Name:       refind
Version:    0.13.2
Release:    %mkrel 1
Summary:    EFI boot manager software
License:    GPLv3
URL:        http://www.rodsbooks.com/refind/
Group:      System/Kernel and hardware
Source:     https://sourceforge.net/projects/refind/files/%version/%name-src-%version.tar.xz
Source1:    pclinuxos.png
Patch0:     refind-0.13.2-pclos-customizations.patch

BuildRequires:  gnu-efi-devel
Requires:       gnu-efi
Requires:       efibootmgr

%define efiarch x64

%description
A graphical boot manager for EFI- and UEFI-based computers, such as all
Intel-based Macs and recent (most 2011 and later) PCs. rEFInd presents a
boot menu showing all the EFI boot loaders on the EFI-accessible
partitions, and optionally BIOS-bootable partitions on Macs and BIOS boot
entries on UEFI PCs with CSMs. EFI-compatible OSes, including Linux,
provide boot loaders that rEFInd can detect and launch. rEFInd can launch
Linux EFI boot loaders such as ELILO, GRUB Legacy, GRUB 2, and 3.3.0 and
later kernels with EFI stub support. EFI filesystem drivers for ext2/3/4fs,
ReiserFS, Btrfs, NTFS, HFS+, and ISO-9660 enable rEFInd to read boot
loaders from these filesystems, too. rEFInd's ability to detect boot
loaders at runtime makes it very easy to use, particularly when paired with
Linux kernels that provide EFI stub support.

Install this package and then run "refind-install" as root to activate.

%prep
%setup -q
%patch0 -p1

%build
make gnuefi
make fs_gnuefi

%install
mkdir -p %{buildroot}%{_datadir}/refind-%{version}/refind/

# Copy the rEFInd binaries (rEFInd proper and drivers) 

install -Dp -m0644 refind/refind*.efi %{buildroot}%{_datadir}/refind-%{version}/refind/
mkdir -p %{buildroot}%{_datadir}/refind-%{version}/refind/drivers_%{efiarch}
cp -a drivers_%{efiarch}/* %{buildroot}%{_datadir}/refind-%{version}/refind/drivers_%{efiarch}/
mkdir -p %{buildroot}%{_datadir}/refind-%{version}/refind/tools_%{efiarch}
install -Dp -m0644 gptsync/gptsync_%{efiarch}.efi %{buildroot}%{_datadir}/refind-%{version}/refind/tools_%{efiarch}/gptsync_%{efiarch}.efi

# Copy configuration and support files 
install -Dp -m0644 refind.conf-sample %{buildroot}%{_datadir}/refind-%{version}/refind/
cp -a icons %{buildroot}%{_datadir}/refind-%{version}/refind/
cp %{SOURCE1} %{buildroot}%{_datadir}/refind-%{version}/refind/icons/os_pclinuxos.png
rm -rf %{buildroot}%{_datadir}/refind-%{version}/refind/icons/svg
install -Dp -m0755 refind-install %{buildroot}%{_datadir}/refind-%{version}/

# Copy documentation 
mkdir -p %{buildroot}%{_datadir}/doc/refind-%{version}
cp -a docs/Styles %{buildroot}%{_datadir}/doc/refind-%{version}/
cp -a docs/refind %{buildroot}%{_datadir}/doc/refind-%{version}/
install -Dp -m0644 NEWS.txt COPYING.txt LICENSE.txt README.txt CREDITS.txt %{buildroot}%{_datadir}/doc/refind-%{version}

# Copy man pages 
mkdir -p %{buildroot}%{_datadir}/man/man8
install -Dp -m0644 docs/man/mvrefind.8 %{buildroot}%{_mandir}/man8
install -Dp -m0644 docs/man/mkrlconf.8 %{buildroot}%{_mandir}/man8
install -Dp -m0644 docs/man/refind-install.8 %{buildroot}%{_mandir}/man8
install -Dp -m0644 docs/man/refind-mkdefault.8 %{buildroot}%{_mandir}/man8

# Copy keys to /etc/refind.d/keys
mkdir -p %{buildroot}/etc/refind.d/keys
install -Dp -m0644 keys/* %{buildroot}%{_sysconfdir}/refind.d/keys

# Copy scripts to /usr/sbin
mkdir -p %{buildroot}%{_sbindir}
install -Dp -m0755 mkrlconf %{buildroot}%{_sbindir}/
install -Dp -m0755 mvrefind %{buildroot}%{_sbindir}/
install -Dp -m0755 refind-mkdefault %{buildroot}%{_sbindir}/
ln -sr %{buildroot}%{_datadir}/refind-%{version}/refind-install %{buildroot}%{_sbindir}

# Copy banners and fonts 
cp -a banners %{buildroot}%{_datadir}/refind-%{version}/
cp -a fonts %{buildroot}%{_datadir}/refind-%{version}/

%files
%defattr(-,root,root -)
%doc %{_datadir}/doc/refind-%{version}
%doc %{_mandir}
%{_sbindir}/mkrlconf
%{_sbindir}/mvrefind
%{_sbindir}/refind-install
%{_sbindir}/refind-mkdefault
%{_datadir}/refind-%{version}
%{_sysconfdir}/refind.d/



%changelog
* Thu May 06 2021 TerryN <terryn94 at gmail.com> 0.13.2-1pclos2021
- update

* Sun Jun 03 2018 TerryN <terryn94 at gmail.com> 0.11.2-1pclos2018
- update
- add pclos icon and adjust default resolution/sizes

* Sat Mar 04 2017 TerryN <terryn94 at gmail.com> 0.10.4-1pclos2017
- Initial version for PCLinuxOS
